@@ -28,6 +28,7 @@
 #include <config.h>
 #include "nautilus-throbber.h"
 
+#include <bonobo/bonobo-ui-toolbar-item.h>
 #include <eel/eel-debug.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-graphic-effects.h>
@@ -62,9 +63,6 @@ struct NautilusThrobberDetails {
 	
 	gboolean ready;
 	gboolean small_mode;
-
-	gboolean button_in;
-	gboolean button_down;
 };
 
 
@@ -82,6 +80,7 @@ GNOME_CLASS_BOILERPLATE (NautilusThrobber, nautilus_throbber,
 /* routines to handle setting and getting the configuration properties of the Bonobo control */
 
 enum {
+	STYLE,
 	THROBBING,
 	LOCATION
 } MyArgs;
@@ -103,24 +102,12 @@ get_bonobo_properties (BonoboPropertyBag *bag,
 	NautilusThrobber *throbber = NAUTILUS_THROBBER (user_data);
 
 	switch (arg_id) {
-		case THROBBING:
-		{
-			BONOBO_ARG_SET_BOOLEAN (arg, throbber->details->timer_task != 0);
-			break;
-		}
+	case THROBBING:
+	{
+		BONOBO_ARG_SET_BOOLEAN (arg, throbber->details->timer_task != 0);
+		break;
+	}
 
-		case LOCATION:
-		{
-			char *location = nautilus_theme_get_theme_data ("throbber", "url");
-			if (location != NULL) {
-				BONOBO_ARG_SET_STRING (arg, location);
-				g_free (location);
-			} else {
-				BONOBO_ARG_SET_STRING (arg, "");			
-			}
-		
-		}
-		
 		default:
 			g_warning ("Unhandled arg %d", arg_id);
 			break;
@@ -136,23 +123,28 @@ set_bonobo_properties (BonoboPropertyBag *bag,
 {
 	NautilusThrobber *throbber = NAUTILUS_THROBBER (user_data);
 	switch (arg_id) {
-		case THROBBING:
-		{
-			gboolean throbbing;
-
-			throbbing = BONOBO_ARG_GET_BOOLEAN (arg);
-			
-			if (throbbing != is_throbbing (throbber)) {
+	case THROBBING:
+	{
+		gboolean throbbing;
+		
+		throbbing = BONOBO_ARG_GET_BOOLEAN (arg);
+		
+		if (throbbing != is_throbbing (throbber)) {
 				if (throbbing) {
 					nautilus_throbber_start (throbber);
 				} else {
 					nautilus_throbber_stop (throbber);
 				}
-			}
-						
-			break;
 		}
-
+		
+		break;
+	}
+	case STYLE:
+	{
+		nautilus_throbber_set_small_mode (throbber, BONOBO_ARG_GET_INT (arg) !=
+						  BONOBO_UI_TOOLBAR_ITEM_STYLE_ICON_AND_TEXT_VERTICAL);
+		break;
+	}
 		default:
 			g_warning ("Unhandled arg %d", arg_id);
 			break;
@@ -239,9 +231,8 @@ nautilus_throbber_instance_init (NautilusThrobber *throbber)
 
 	bonobo_property_bag_add (throbber->details->property_bag, "throbbing", THROBBING, BONOBO_ARG_BOOLEAN, NULL,
 				 "Throbber active", 0);
-	bonobo_property_bag_add (throbber->details->property_bag, "location", LOCATION, BONOBO_ARG_STRING, NULL,
-				 "associated URL", 0);
-	
+	bonobo_property_bag_add (throbber->details->property_bag, "style", STYLE, BONOBO_ARG_INT, NULL, NULL,
+				 Bonobo_PROPERTY_WRITEABLE);
 	nautilus_throbber_load_images (throbber);
 	gtk_widget_show (widget);
 
@@ -290,10 +281,10 @@ static int
 nautilus_throbber_expose (GtkWidget *widget, GdkEventExpose *event)
 {
 	NautilusThrobber *throbber;
-	GdkPixbuf *pixbuf, *massaged_pixbuf;
+	GdkPixbuf *pixbuf;
 	int x_offset, y_offset, width, height;
 	GdkRectangle pix_area, dest;
-
+	
 	g_return_val_if_fail (NAUTILUS_IS_THROBBER (widget), FALSE);
 
 	throbber = NAUTILUS_THROBBER (widget);
@@ -306,17 +297,6 @@ nautilus_throbber_expose (GtkWidget *widget, GdkEventExpose *event)
 		return FALSE;
 	}
 
-	/* Get the right tint on the image */
-	if (throbber->details->button_in) {
-		if (throbber->details->button_down) {
-			massaged_pixbuf = eel_create_darkened_pixbuf (pixbuf, 0.8 * 255, 0.8 * 255);
-		} else {
-			massaged_pixbuf = eel_create_spotlight_pixbuf (pixbuf);
-		}
-		g_object_unref (pixbuf);
-		pixbuf = massaged_pixbuf;
-	}
-
 	width = gdk_pixbuf_get_width (pixbuf);
 	height = gdk_pixbuf_get_height (pixbuf);
 
@@ -333,15 +313,12 @@ nautilus_throbber_expose (GtkWidget *widget, GdkEventExpose *event)
 		g_object_unref (pixbuf);
 		return FALSE;
 	}
-	
-	gdk_pixbuf_render_to_drawable_alpha (
-		pixbuf, widget->window, 
-		dest.x - x_offset, dest.y - y_offset,
-		dest.x, dest.y,
-		dest.width, dest.height,
-		GDK_PIXBUF_ALPHA_BILEVEL, 128,
-		GDK_RGB_DITHER_MAX,
-		0, 0);
+
+	gdk_draw_pixbuf (widget->window, NULL, pixbuf,
+			 dest.x - x_offset, dest.y - y_offset,
+			 dest.x, dest.y,
+			 dest.width, dest.height,
+			 GDK_RGB_DITHER_MAX, 0, 0);
 
 	g_object_unref (pixbuf);
 
@@ -391,21 +368,21 @@ nautilus_throbber_start (NautilusThrobber *throbber)
 	}
 
 	if (throbber->details->timer_task != 0) {
-		gtk_timeout_remove (throbber->details->timer_task);
+		g_source_remove (throbber->details->timer_task);
 	}
 	
 	/* reset the frame count */
 	throbber->details->current_frame = 0;
-	throbber->details->timer_task = gtk_timeout_add (throbber->details->delay,
-							 bump_throbber_frame,
-							 throbber);
+	throbber->details->timer_task = g_timeout_add (throbber->details->delay,
+						       bump_throbber_frame,
+						       throbber);
 }
 
 static void
 nautilus_throbber_remove_update_callback (NautilusThrobber *throbber)
 {
 	if (throbber->details->timer_task != 0) {
-		gtk_timeout_remove (throbber->details->timer_task);
+		g_source_remove (throbber->details->timer_task);
 	}
 	
 	throbber->details->timer_task = 0;
@@ -465,8 +442,8 @@ load_themed_image (const char *file_name, const char *image_theme, gboolean smal
 		
 		if (small_mode && pixbuf) {
 			temp_pixbuf = gdk_pixbuf_scale_simple (pixbuf,
-							       gdk_pixbuf_get_width (pixbuf) / 2,
-							       gdk_pixbuf_get_height (pixbuf) / 2,
+							       gdk_pixbuf_get_width (pixbuf) * 2 / 3,
+							       gdk_pixbuf_get_height (pixbuf) * 2 / 3,
 							       GDK_INTERP_BILINEAR);
 			g_object_unref (pixbuf);
 			pixbuf = temp_pixbuf;
@@ -514,6 +491,7 @@ nautilus_throbber_load_images (NautilusThrobber *throbber)
 	for (index = 1; index <= throbber->details->max_frame; index++) {
 		throbber_frame_name = make_throbber_frame_name (index);
 		pixbuf = load_themed_image (throbber_frame_name, image_theme, throbber->details->small_mode);
+
 		g_free (throbber_frame_name);
 		if (pixbuf == NULL) {
 			throbber->details->max_frame = index - 1;
@@ -526,97 +504,6 @@ nautilus_throbber_load_images (NautilusThrobber *throbber)
 	g_free (image_theme);
 }
 
-static gboolean
-nautilus_throbber_enter_notify_event (GtkWidget *widget, GdkEventCrossing *event)
-{
-	NautilusThrobber *throbber;
-
-	throbber = NAUTILUS_THROBBER (widget);
-
-	if (!throbber->details->button_in) {
-		throbber->details->button_in = TRUE;
-		gtk_widget_queue_draw (widget);
-	}
-
-	return GNOME_CALL_PARENT_WITH_DEFAULT
-		(GTK_WIDGET_CLASS, enter_notify_event, (widget, event), FALSE);
-}
-
-static gboolean
-nautilus_throbber_leave_notify_event (GtkWidget *widget, GdkEventCrossing *event)
-{
-	NautilusThrobber *throbber;
-
-	throbber = NAUTILUS_THROBBER (widget);
-
-	if (throbber->details->button_in) {
-		throbber->details->button_in = FALSE;
-		gtk_widget_queue_draw (widget);
-	}
-
-	return GNOME_CALL_PARENT_WITH_DEFAULT
-		(GTK_WIDGET_CLASS, leave_notify_event, (widget, event), FALSE);
-}
-
-/* handle button presses by posting a change on the "location" property */
-
-static gboolean
-nautilus_throbber_button_press_event (GtkWidget *widget, GdkEventButton *event)
-{
-	NautilusThrobber *throbber;
-
-	throbber = NAUTILUS_THROBBER (widget);
-
-	if (event->button == 1) {
-		throbber->details->button_down = TRUE;
-		throbber->details->button_in = TRUE;
-		gtk_widget_queue_draw (widget);
-		return TRUE;
-	}
-
-	return GNOME_CALL_PARENT_WITH_DEFAULT
-		(GTK_WIDGET_CLASS, button_press_event, (widget, event), FALSE);
-}
-
-static void
-nautilus_throbber_set_location (NautilusThrobber *throbber)
-{
-	char *location;
-	BonoboArg *location_arg;
-
-	location = nautilus_theme_get_theme_data ("throbber", "url");
-	if (location != NULL) {
-		location_arg = bonobo_arg_new (BONOBO_ARG_STRING);
-		BONOBO_ARG_SET_STRING (location_arg, location);
-		bonobo_event_source_notify_listeners_full (
-			throbber->details->property_bag->es,
-			"Bonobo/Property", "change", "location",
-			location_arg, NULL);
-		bonobo_arg_release (location_arg);
-		g_free (location);
-	}
-}
-
-static gboolean
-nautilus_throbber_button_release_event (GtkWidget *widget, GdkEventButton *event)
-{	
-	NautilusThrobber *throbber;
-	
-	throbber = NAUTILUS_THROBBER (widget);
-
-	if (event->button == 1) {
-		if (throbber->details->button_in) {
-			nautilus_throbber_set_location (throbber);
-		}
-		throbber->details->button_down = FALSE;
-		gtk_widget_queue_draw (widget);
-		return TRUE;
-	}
-	
-	return GNOME_CALL_PARENT_WITH_DEFAULT
-		(GTK_WIDGET_CLASS, button_release_event, (widget, event), FALSE);
-}
-
 void
 nautilus_throbber_set_small_mode (NautilusThrobber *throbber, gboolean new_mode)
 {
@@ -675,10 +562,6 @@ nautilus_throbber_class_init (NautilusThrobberClass *class)
 	G_OBJECT_CLASS (class)->finalize = nautilus_throbber_finalize;
 
 	widget_class->expose_event = nautilus_throbber_expose;
-	widget_class->button_press_event = nautilus_throbber_button_press_event;
-	widget_class->button_release_event = nautilus_throbber_button_release_event;
-	widget_class->enter_notify_event = nautilus_throbber_enter_notify_event;
-	widget_class->leave_notify_event = nautilus_throbber_leave_notify_event;
 	widget_class->size_request = nautilus_throbber_size_request;	
 	widget_class->map = nautilus_throbber_map;
 	widget_class->get_accessible = nautilus_throbber_get_accessible;
@@ -726,94 +609,6 @@ nautilus_throbber_accessible_image_interface_init (AtkImageIface *iface)
 	iface->get_image_size = nautilus_throbber_accessible_image_get_size;
 }
 
-/* AtkAction interface */
-
-enum {
-	ACTION_ACTIVATE,
-	LAST_ACTION
-};
-
-static const char *nautilus_throbber_accessible_action_names[] = {
-	"activate",
-	NULL
-};
-
-static const char *nautilus_throbber_accessible_action_descriptions[] = {
-	"Activate selected items",
-	NULL
-};
-
-
-static gboolean
-nautilus_throbber_accessible_do_action (AtkAction *accessible, int i)
-{
-	GtkWidget *widget;
-
-	g_return_val_if_fail (i < LAST_ACTION, FALSE);
-
-	widget = GTK_ACCESSIBLE (accessible)->widget;
-	if (!widget) {
-		return FALSE;
-	}
-	
-	switch (i) {
-	case ACTION_ACTIVATE :
-		nautilus_throbber_set_location (NAUTILUS_THROBBER (widget));
-		return TRUE;
-	default:
-		return FALSE;
-	}
-}
-
-static int
-nautilus_throbber_accessible_get_n_actions (AtkAction *accessible)
-{
-	return LAST_ACTION;
-}
-
-static const char *
-nautilus_throbber_accessible_action_get_description (AtkAction *accessible, 
-							   int i)
-{
-	g_return_val_if_fail (i < LAST_ACTION, NULL);
-
-	return nautilus_throbber_accessible_action_descriptions[i];
-}
-
-static const char *
-nautilus_throbber_accessible_action_get_name (AtkAction *accessible, int i)
-{
-	g_return_val_if_fail (i < LAST_ACTION, NULL);
-
-	return nautilus_throbber_accessible_action_names [i];
-}
-
-static const char *
-nautilus_throbber_accessible_action_get_keybinding (AtkAction *accessible, 
-						    int        i)
-{
-	return NULL;
-}
-
-static gboolean
-nautilus_throbber_accessible_action_set_description (AtkAction  *accessible, 
-						     int         i, 
-						     const char *description)
-{
-	return FALSE;
-}
-
-static void
-nautilus_throbber_accessible_action_interface_init (AtkActionIface *iface)
-{
-	iface->do_action = nautilus_throbber_accessible_do_action;
-	iface->get_n_actions = nautilus_throbber_accessible_get_n_actions;
-	iface->get_description = nautilus_throbber_accessible_action_get_description;
-	iface->get_name = nautilus_throbber_accessible_action_get_name;
-	iface->get_keybinding = nautilus_throbber_accessible_action_get_keybinding;
-	iface->set_description = nautilus_throbber_accessible_action_set_description;
-}
-
 static GType
 nautilus_throbber_accessible_get_type (void)
 {
@@ -822,12 +617,6 @@ nautilus_throbber_accessible_get_type (void)
 	/* Action interface
 	   Name etc. ... */
         if (!type) {
-                static GInterfaceInfo atk_action_info = {
-                        (GInterfaceInitFunc) nautilus_throbber_accessible_action_interface_init,
-                        (GInterfaceFinalizeFunc) NULL,
-                        NULL
-                };              
-
 		static const GInterfaceInfo atk_image_info = {
 			(GInterfaceInitFunc) nautilus_throbber_accessible_image_interface_init,
 			(GInterfaceFinalizeFunc) NULL,
@@ -839,8 +628,6 @@ nautilus_throbber_accessible_get_type (void)
 			 GTK_TYPE_IMAGE,
 			 nautilus_throbber_accessible_class_init);
 		
-                g_type_add_interface_static (type, ATK_TYPE_ACTION,
-                                             &atk_action_info);
                 g_type_add_interface_static (type, ATK_TYPE_IMAGE,
                                              &atk_image_info);
         }
